@@ -6,13 +6,13 @@ use warnings FATAL => 'all';
 use Apache2::RequestRec ();
 use Apache2::RequestUtil ();
 use Apache2::RequestIO ();
-use Apache2::ModSSL ();
 
 use Apache2::Const -compile => qw(OK DECLINED);
 
 sub handler {
   my $r = shift;
 
+  eval "require Apache2::ModSSL;";
   $r->content_type('text/plain');
   my $rc;
   if( $r->uri=~m!/ext$! ) {
